@@ -38,6 +38,9 @@ FAILEDOPERATION_FLOWNUMEXCEED = 'FailedOperation.FlowNumExceed'
 # 已授权。
 FAILEDOPERATION_HASAUTHORIZED = 'FailedOperation.HasAuthorized'
 
+# 自动签许可额度不足
+FAILEDOPERATION_LICENSENOQUOTA = 'FailedOperation.LicenseNoQuota'
+
 # 无角色授权，请确认数据是否存在
 FAILEDOPERATION_NOROLEAUTH = 'FailedOperation.NoRoleAuth'
 
@@ -236,12 +239,12 @@ INVALIDPARAMETER_NAME = 'InvalidParameter.Name'
 # 不支持的手机号。
 INVALIDPARAMETER_NONSUPPORTMOBILE = 'InvalidParameter.NonsupportMobile'
 
-# 参数Offset不正确
-INVALIDPARAMETER_OFFSET = 'InvalidParameter.Offset'
-
 # OpenId不合法。
 INVALIDPARAMETER_OPENID = 'InvalidParameter.OpenId'
 
+# 用户ID不正确
+INVALIDPARAMETER_OPERATORID = 'InvalidParameter.OperatorId'
+
 # OrganizationId不合法。
 INVALIDPARAMETER_ORGANIZATIONID = 'InvalidParameter.OrganizationId'
 
@@ -257,6 +260,9 @@ INVALIDPARAMETER_RESOURCETYPE = 'InvalidParameter.ResourceType'
 # 角色ID不正确
 INVALIDPARAMETER_ROLEID = 'InvalidParameter.RoleId'
 
+# 存在敏感词
+INVALIDPARAMETER_SENSITIVE = 'InvalidParameter.Sensitive'
+
 # 上传的文件包含敏感（不合规）的内容，请确认。
 INVALIDPARAMETER_SENSITIVEFILECONTENT = 'InvalidParameter.SensitiveFileContent'
 
@@ -440,12 +446,18 @@ OPERATIONDENIED_OPERATETYPE = 'OperationDenied.OperateType'
 # 操作者权限不足。
 OPERATIONDENIED_OPERATORHASNOPERMISSION = 'OperationDenied.OperatorHasNoPermission'
 
+# 企业已经注销中
+OPERATIONDENIED_ORGANIZATIONCLOSING = 'OperationDenied.OrganizationClosing'
+
 # 超出查询上限。
 OPERATIONDENIED_OUTQUERYLIMIT = 'OperationDenied.OutQueryLimit'
 
 # 当前企业员工没有开通境外签署能力。
 OPERATIONDENIED_OVERSEAABILITYNOTOPEN = 'OperationDenied.OverseaAbilityNotOpen'
 
+# 该用户名下没有可用签名
+OPERATIONDENIED_PERSONHASNOSIGNATURE = 'OperationDenied.PersonHasNoSignature'
+
 # 该用户已关闭或者未开启自动签服务
 OPERATIONDENIED_PERSONNOOPENSERVERSIGN = 'OperationDenied.PersonNoOpenServerSign'
 
